pub struct AgentProfile {
pub agent_id: String,
pub name: String,
pub version: String,
pub capabilities: Vec<String>,
pub auth_token: Option<String>,
pub token_expires_at: Option<DateTime<Utc>>,
pub metadata: HashMap<String, Value>,
}Expand description
Agent profile for authentication and identity propagation.
Fields
agent_id: StringUnique agent identifier.
name: StringHuman-readable agent name.
version: StringAgent version.
capabilities: Vec<String>Capabilities this agent advertises.
auth_token: Option<String>Authentication token for this agent.
token_expires_at: Option<DateTime<Utc>>Token expiration time.
metadata: HashMap<String, Value>Metadata for custom properties.
Implementations
Sourceimpl AgentProfile
impl AgentProfile
Sourcepub fn new(agent_id: impl Into<String>, name: impl Into<String>) -> AgentProfile
pub fn new(agent_id: impl Into<String>, name: impl Into<String>) -> AgentProfile
Create a new agent profile.
Sourcepub fn with_capability(self, capability: impl Into<String>) -> AgentProfile
pub fn with_capability(self, capability: impl Into<String>) -> AgentProfile
Add a capability string.
Sourcepub fn with_auth_token(
self,
token: impl Into<String>,
expires_at: Option<DateTime<Utc>>,
) -> AgentProfile
pub fn with_auth_token( self, token: impl Into<String>, expires_at: Option<DateTime<Utc>>, ) -> AgentProfile
Set the authentication token (and optional expiry) for this profile.
Sourcepub fn is_token_valid(&self) -> bool
pub fn is_token_valid(&self) -> bool
Return whether the currently attached token exists and is not expired.
Sourcepub fn generate_token(&mut self, validity_hours: i64)
pub fn generate_token(&mut self, validity_hours: i64)
Generate a new bearer token for this agent and set token_expires_at.
The generated token is URL-safe alphanumeric and intended for use as a
Authorization: Bearer <token> credential.